@@ -1,4 +1,6 @@
 circpurka.reg <- function(y, x, rads = TRUE, xnew = NULL) {
+
+  tic <- proc.time()
   if ( !is.matrix(y) ) {
     if ( !rads )   y <- y * pi/180
     z <- cbind( cos(y), sin(y) )
@@ -10,7 +12,7 @@ circpurka.reg <- function(y, x, rads = TRUE, xnew = NULL) {
     est <- x %*% be
     a <- sqrt( Rfast::rowsums(est^2) )
     est <- est / a
-    - sum( log(a) - log(1 - exp(-a * pi) )  - a * acos( z * est ) )
+    - sum( log(a) - log(1 - exp(-a * pi) ) - a * acos( z * est ) )
   }
 
   ini <- as.vector( solve( crossprod(x), crossprod(x, z) ) )
@@ -24,7 +26,9 @@ circpurka.reg <- function(y, x, rads = TRUE, xnew = NULL) {
     lik2 <- mod$value
   }
   be <- matrix(mod$par, ncol = 2)
-  covb <- solve( mod$hessian )
+  seb <- solve( mod$hessian )
+  seb <- matrix( sqrt( diag(seb) ), ncol = 2)
+  runtime <- proc.time() - tic
 
   est <- NULL
   if ( !is.null(xnew) ) {
@@ -33,8 +37,8 @@ circpurka.reg <- function(y, x, rads = TRUE, xnew = NULL) {
     est <- ( atan(est[, 2]/est[, 1]) + pi * I(est[, 1] < 0) ) %% (2 * pi)
     if ( !rads )  est <- est * 180 / pi
   }
-  colnames(be) <- c("Cosinus of y", "Sinus of y")
-  rownames(be) <- colnames(x)
+  colnames(be) <- colnames(seb) <- c("Cosinus of y", "Sinus of y")
+  rownames(be) <- rownames(seb) <- colnames(x)
 
-  list( value = - mod$value - dim(x)[1] * log(2), be = be, covb = covb, est = est )
+  list( runtime = runtime, be = be, seb = seb, loglik = - mod$value - dim(x)[1] * log(2), est = est )
 }
