@@ -31,8 +31,15 @@ embedcirc.perm <- function(u1, u2, rads = TRUE, B = 999) {
     Rbar <- sqrt(C^2 + S^2)/n
     pfb[i] <- (n - 2) * ( sum(ni * Rbi) - n * Rbar^2 ) / ( n - sum(ni * Rbi) )
   }
-  pvalue <- ( sum(pfb > Fb) + 1 ) / (B + 1)
-  res <- c(Fb, pvalue)
-  names(res) <- c("test", "p-value")
-  res
+
+  p.value <- ( sum(pfb > Fb) + 1 ) / (B + 1)
+  statistic <- Fb  ;  names(statistic) <- "Embedding test statistic"
+  parameter <- "NA"  ;  names(parameter) <- "df"
+  alternative <- "The 2 circular means differ"
+  method <- "Permutation ANOVA for 2 circular means using the embedding approach"
+  data.name <- c("data ", " groups")
+  result <- list( statistic = statistic, parameter = parameter, p.value = p.value,
+                  alternative = alternative, method = method, data.name = data.name )
+  class(result) <- "htest"
+  return(result)
 }
