@@ -25,8 +25,14 @@ het.perm <- function(x1, x2, B = 999) {
     tw <- Rfast::colsums(kapa * ni * mi)
     ptt[i] <- sum( kapa * ni * sqrt( Rfast::rowsums(mi^2) ) ) - sqrt( sum(tw^2) )
   }
-  pvalue <- ( sum(ptt > Tt) + 1 ) / (B + 1)
-  res <- c(2 * Tt, pvalue)
-  names(res) <- c('test', 'p-value')
-  res
+  p.value <- ( sum(ptt > Tt) + 1 ) / (B + 1)
+  statistic <- 2 * Tt  ;   names(statistic) <- "Permutation het test statistic"
+  parameter <- "NA"     ;   names(parameter) <- "df"
+  alternative <- "The 2 directional mean vectors differ"
+  method <- "Permutation ANOVA for 2 directional mean vectors using the heterogeneous approach"
+  data.name <- c("data ", " groups")
+  result <- list( statistic = statistic, parameter = parameter, p.value = p.value,
+                  alternative = alternative, method = method, data.name = data.name )
+  class(result) <- "htest"
+  return(result)
 }
